@@ -1,5 +1,5 @@
 from pydantic import BaseModel, Field
-from typing import Generic, TypeVar
+from typing import Annotated, Generic, Literal, TypeVar
 
 
 OldDataT = TypeVar("OldDataT")
@@ -19,3 +19,9 @@ class DataMixin(BaseModel, Generic[AnyDataT]):
 
 
 ModelDataT = TypeVar("ModelDataT", bound=BaseModel)
+
+
+class PingData(BaseModel):
+    message: Annotated[Literal["pong"], Field("pong", description="Ping response")] = (
+        "pong"
+    )
