@@ -125,7 +125,7 @@ AnyErrorDescriptor = (
 )
 
 
-class Factory:
+class ErrorDescriptorFactory:
     @overload
     @staticmethod
     def cls_from_code(
@@ -351,4 +351,4 @@ class Factory:
             obj["message"] = message
         if description is not None:
             obj["description"] = description
-        return Factory.cls_from_code(code).model_validate(obj)
+        return ErrorDescriptorFactory.cls_from_code(code).model_validate(obj)
