@@ -1,5 +1,5 @@
 from enum import StrEnum
-from maleo.types.string import ListOfStrings
+from maleo.types.string import ListOfStrs
 
 
 class ErrorType(StrEnum):
@@ -17,11 +17,11 @@ class ErrorType(StrEnum):
     SERVICE_UNAVAILABLE = "server.service_unavailable"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
-class Code(StrEnum):
+class ErrorCode(StrEnum):
     BAD_REQUEST = "MAL-ERR-CLI-BDR-001"
     UNAUTHORIZED = "MAL-ERR-CLI-ATH-001"
     FORBIDDEN = "MAL-ERR-CLI-FBD-001"
@@ -36,5 +36,5 @@ class Code(StrEnum):
     SERVICE_UNAVAILABLE = "MAL-ERR-SRV-SUN-001"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
