@@ -1,14 +1,12 @@
 from pydantic import BaseModel, Field
 from typing import Any
 from typing_extensions import Annotated
-from maleo.types.string import OptionalListOfStrings
+from maleo.types.string import OptListOfStrs
 
 
 class ErrorMetadata(BaseModel):
     details: Annotated[Any, Field(None, description="Details")] = None
-    traceback: Annotated[
-        OptionalListOfStrings, Field(None, description="Traceback")
-    ] = None
+    traceback: Annotated[OptListOfStrs, Field(None, description="Traceback")] = None
 
 
 class ErrorMetadataMixin(BaseModel):
