@@ -1,7 +1,12 @@
 import traceback as tb
 from fastapi.responses import JSONResponse
+from google.cloud.pubsub_v1.publisher.futures import Future
+from logging import Logger
 from typing import Any, Generic, Literal, Type, overload
 from uuid import uuid4
+from maleo.logging.enums import Level
+from maleo.types.boolean import OptBool
+from maleo.types.dict import OptStrToStrDict
 from maleo.types.string import ListOfStrs, OptStr
 from maleo.types.uuid import OptUUID
 from ..application import ApplicationContext, OptApplicationContext
@@ -23,6 +28,7 @@ from ..error import (
     ServiceUnavailableError,
     AnyErrorT,
 )
+from ..google import ListOfPublisherHandlers
 from ..operation.action.resource import (
     ResourceOperationActions,
     AnyResourceOperationAction,
@@ -247,6 +253,9 @@ class MaleoException(
         self.authentication = authentication
         self.authorization = authorization
         self.impersonation = impersonation
+        self._logged: bool = False
+        self._published: bool = False
+        self._futures: list[Future] = []
 
         if response is not None:
             self.response: ErrorResponseT = self.response_cls.model_validate(
@@ -655,6 +664,76 @@ class MaleoException(
                     response=self.response,
                 )
 
+    def log_operation(
+        self,
+        logger: Logger,
+        level: Level = Level.ERROR,
+        *,
+        exc_info: OptBool = None,
+        additional_extra: OptStrToStrDict = None,
+        override_extra: OptStrToStrDict = None,
+        additional_labels: OptStrToStrDict = None,
+        override_labels: OptStrToStrDict = None,
+    ):
+        if not self._logged:
+            self.operation.log(
+                logger,
+                level,
+                exc_info=exc_info,
+                additional_extra=additional_extra,
+                override_extra=override_extra,
+                additional_labels=additional_labels,
+                override_labels=override_labels,
+            )
+            self._logged = True
+
+    def publish_operation(
+        self,
+        logger: Logger,
+        publishers: ListOfPublisherHandlers = [],
+        *,
+        additional_labels: OptStrToStrDict = None,
+        override_labels: OptStrToStrDict = None,
+    ) -> list[Future]:
+        if not self._published:
+            futures = self.operation.publish(
+                logger,
+                publishers,
+                additional_labels=additional_labels,
+                override_labels=override_labels,
+            )
+            self._published = True
+            self._futures = futures
+        return self._futures
+
+    def log_and_publish_operation(
+        self,
+        logger: Logger,
+        publishers: ListOfPublisherHandlers = [],
+        level: Level = Level.ERROR,
+        *,
+        exc_info: OptBool = None,
+        additional_extra: OptStrToStrDict = None,
+        override_extra: OptStrToStrDict = None,
+        additional_labels: OptStrToStrDict = None,
+        override_labels: OptStrToStrDict = None,
+    ) -> list[Future]:
+        self.log_operation(
+            logger,
+            level,
+            exc_info=exc_info,
+            additional_extra=additional_extra,
+            override_extra=override_extra,
+            additional_labels=additional_labels,
+            override_labels=override_labels,
+        )
+        return self.publish_operation(
+            logger,
+            publishers,
+            additional_labels=additional_labels,
+            override_labels=override_labels,
+        )
+
 
 class ClientException(
     MaleoException[
