@@ -51,7 +51,7 @@ from .exc import (
 )
 
 
-class Factory:
+class MaleoExceptionFactory:
     @overload
     @classmethod
     def cls_from_code(
