@@ -1,10 +1,10 @@
 from pydantic import BaseModel, Field
-from typing import Dict, Generic, Optional, TypeVar, Union
+from typing import Generic, TypeVar
 from .mixins.general import Success, Descriptor, Other
 
 
 AnyMetadataT = TypeVar("AnyMetadataT")
-ModelMetadataT = TypeVar("ModelMetadataT", bound=Optional[BaseModel])
+ModelMetadataT = TypeVar("ModelMetadataT", bound=BaseModel | None)
 
 
 class MetadataMixin(BaseModel, Generic[AnyMetadataT]):
@@ -16,6 +16,6 @@ class FieldExpansionMetadata(Other, Descriptor[str], Success[bool]):
 
 
 class FieldExpansionMetadataMixin(BaseModel):
-    field_expansion: Optional[Union[str, Dict[str, FieldExpansionMetadata]]] = Field(
+    field_expansion: str | dict[str, FieldExpansionMetadata] | None = Field(
         None, description="Field expansion metadata"
     )
