@@ -1,9 +1,9 @@
 import re
 from datetime import datetime
 from pydantic import BaseModel, Field, field_validator, model_validator
-from typing import Annotated, List, Optional, Self, TypeGuard, Union, overload
-from maleo.types.datetime import OptionalDatetime
-from maleo.types.string import ListOfStrings
+from typing import Annotated, Self, TypeGuard, overload
+from maleo.types.datetime import OptDatetime
+from maleo.types.string import ListOfStrs
 from .identity import Name
 from .timestamp import FromTimestamp, ToTimestamp
 
@@ -17,13 +17,13 @@ DATE_FILTER_PATTERN = re.compile(DATE_FILTER_REGEX)
 
 
 class DateFilter(
-    ToTimestamp[OptionalDatetime],
-    FromTimestamp[OptionalDatetime],
+    ToTimestamp[OptDatetime],
+    FromTimestamp[OptDatetime],
     Name[str],
 ):
     name: Annotated[str, Field(..., description="Name", min_length=1)]
-    from_date: Annotated[OptionalDatetime, Field(None, description="From date")] = None
-    to_date: Annotated[OptionalDatetime, Field(None, description="To date")] = None
+    from_date: Annotated[OptDatetime, Field(None, description="From date")] = None
+    to_date: Annotated[OptDatetime, Field(None, description="To date")] = None
 
     def _validate_timestamps(self):
         if self.from_date is None and self.to_date is None:
@@ -65,35 +65,38 @@ class DateFilter(
         return filter_string
 
 
-OptionalDateFilter = Optional[DateFilter]
-ListOfDateFilters = List[DateFilter]
-OptionalListOfDateFilters = Optional[OptionalDateFilter]
+OptDateFilter = DateFilter | None
+ListOfDateFilters = list[DateFilter]
+OptListOfDateFilters = OptDateFilter | None
+
+
+AnyFilters = ListOfDateFilters | ListOfStrs
 
 
 def is_date_filters(
-    filters: Union[ListOfDateFilters, ListOfStrings],
+    filters: AnyFilters,
 ) -> TypeGuard[ListOfDateFilters]:
     return all(isinstance(filter, DateFilter) for filter in filters)
 
 
 def is_filters(
-    filters: Union[ListOfDateFilters, ListOfStrings],
-) -> TypeGuard[ListOfStrings]:
+    filters: AnyFilters,
+) -> TypeGuard[ListOfStrs]:
     return all(isinstance(filter, str) for filter in filters)
 
 
 class Filters(BaseModel):
     filters: Annotated[
-        ListOfStrings,
+        ListOfStrs,
         Field(
-            default_factory=list,
+            list[str](),
             description="Date range filters with '<COLUMN_NAME>|from::<ISO_DATETIME>|to::<ISO_DATETIME>' format",
         ),
     ] = list[str]()
 
     @field_validator("filters", mode="after")
     @classmethod
-    def validate_filters_pattern(cls, value: ListOfStrings) -> ListOfStrings:
+    def validate_filters_pattern(cls, value: ListOfStrs) -> ListOfStrs:
         for v in value:
             match = DATE_FILTER_PATTERN.match(v)
             if not match:
@@ -112,33 +115,23 @@ class Filters(BaseModel):
 class DateFilters(BaseModel):
     date_filters: Annotated[
         ListOfDateFilters,
-        Field(
-            default_factory=list[DateFilter], description="Date filters to be applied"
-        ),
+        Field(list[DateFilter](), description="Date filters to be applied"),
     ] = list[DateFilter]()
 
     @classmethod
-    def from_filters(cls, filters: ListOfStrings) -> "DateFilters":
+    def from_filters(cls, filters: ListOfStrs) -> "DateFilters":
         return cls(date_filters=[DateFilter.from_string(filter) for filter in filters])
 
     @property
-    def filters(self) -> ListOfStrings:
+    def filters(self) -> ListOfStrs:
         return [filter.to_string() for filter in self.date_filters]
 
 
 @overload
-def convert(filters: ListOfDateFilters) -> ListOfStrings: ...
+def convert(filters: ListOfDateFilters) -> ListOfStrs: ...
 @overload
-def convert(filters: ListOfStrings) -> ListOfDateFilters: ...
-def convert(
-    filters: Union[
-        ListOfDateFilters,
-        ListOfStrings,
-    ],
-) -> Union[
-    ListOfStrings,
-    ListOfDateFilters,
-]:
+def convert(filters: ListOfStrs) -> ListOfDateFilters: ...
+def convert(filters: AnyFilters) -> AnyFilters:
     if is_date_filters(filters):
         return [filter.to_string() for filter in filters]
     elif is_filters(filters):
