@@ -1,8 +1,8 @@
 import re
 from pydantic import BaseModel, Field, field_validator
-from typing import Annotated, List, Optional, TypeGuard, Union, overload
+from typing import Annotated, TypeGuard, overload
 from maleo.enums.order import Order as OrderEnum
-from maleo.types.string import ListOfStrings
+from maleo.types.string import ListOfStrs
 from .general import Order
 from .identity import Name
 
@@ -33,26 +33,29 @@ class SortColumn(
         return f"{self.name}.{self.order}"
 
 
-OptionalSortColumn = Optional[SortColumn]
-ListOfSortColumns = List[SortColumn]
-OptionalListOfSortColumns = Optional[OptionalSortColumn]
+OptSortColumn = SortColumn | None
+ListOfSortColumns = list[SortColumn]
+OptListOfSortColumns = ListOfSortColumns | None
+
+
+AnySorts = ListOfSortColumns | ListOfStrs
 
 
 def is_sort_columns(
-    sorts: Union[ListOfSortColumns, ListOfStrings],
+    sorts: AnySorts,
 ) -> TypeGuard[ListOfSortColumns]:
     return all(isinstance(sort, SortColumn) for sort in sorts)
 
 
 def is_sorts(
-    sorts: Union[ListOfSortColumns, ListOfStrings],
-) -> TypeGuard[ListOfStrings]:
+    sorts: AnySorts,
+) -> TypeGuard[ListOfStrs]:
     return all(isinstance(sort, str) for sort in sorts)
 
 
 class Sorts(BaseModel):
     sorts: Annotated[
-        ListOfStrings,
+        ListOfStrs,
         Field(
             ["id.asc"],
             description="Column sorts with '<COLUMN_NAME>.<ASC|DESC>' format",
@@ -61,7 +64,7 @@ class Sorts(BaseModel):
 
     @field_validator("sorts", mode="after")
     @classmethod
-    def validate_sorts_pattern(cls, value: ListOfStrings) -> ListOfStrings:
+    def validate_sorts_pattern(cls, value: ListOfStrs) -> ListOfStrs:
         for v in value:
             match = SORT_COLUMN_PATTERN.match(v)
             if not match:
@@ -73,13 +76,13 @@ class Sorts(BaseModel):
         return cls(sorts=[sort.to_string() for sort in sort_columns])
 
     @property
-    def sort_columns(self) -> List[SortColumn]:
+    def sort_columns(self) -> ListOfSortColumns:
         return [SortColumn.from_string(sort) for sort in self.sorts]
 
 
 class SortColumns(BaseModel):
     sort_columns: Annotated[
-        List[SortColumn],
+        ListOfSortColumns,
         Field(
             [SortColumn(name="id", order=OrderEnum.ASC)],
             description="List of columns to be sorted",
@@ -87,27 +90,19 @@ class SortColumns(BaseModel):
     ] = [SortColumn(name="id", order=OrderEnum.ASC)]
 
     @classmethod
-    def from_sorts(cls, sorts: ListOfStrings) -> "SortColumns":
+    def from_sorts(cls, sorts: ListOfStrs) -> "SortColumns":
         return cls(sort_columns=[SortColumn.from_string(sort) for sort in sorts])
 
     @property
-    def sorts(self) -> ListOfStrings:
+    def sorts(self) -> ListOfStrs:
         return [sort.to_string() for sort in self.sort_columns]
 
 
 @overload
-def convert(sorts: ListOfSortColumns) -> ListOfStrings: ...
+def convert(sorts: ListOfSortColumns) -> ListOfStrs: ...
 @overload
-def convert(sorts: ListOfStrings) -> ListOfSortColumns: ...
-def convert(
-    sorts: Union[
-        ListOfSortColumns,
-        ListOfStrings,
-    ],
-) -> Union[
-    ListOfStrings,
-    ListOfSortColumns,
-]:
+def convert(sorts: ListOfStrs) -> ListOfSortColumns: ...
+def convert(sorts: AnySorts) -> AnySorts:
     if is_sort_columns(sorts):
         return [sort.to_string() for sort in sorts]
     elif is_sorts(sorts):
