@@ -13,6 +13,14 @@ class ToTimestamp(BaseModel, Generic[OptDatetimeT]):
     to_date: OptDatetimeT = Field(..., description="To date")
 
 
+class StartTimestamp(BaseModel, Generic[OptDatetimeT]):
+    started_at: OptDatetimeT = Field(..., description="started_at timestamp")
+
+
+class FinishTimestamp(BaseModel, Generic[OptDatetimeT]):
+    finished_at: OptDatetimeT = Field(..., description="finished_at timestamp")
+
+
 class ExecutionTimestamp(BaseModel, Generic[OptDatetimeT]):
     executed_at: OptDatetimeT = Field(..., description="executed_at timestamp")
 
@@ -97,3 +105,7 @@ class Duration(BaseModel, Generic[OptFloatT]):
 
 class InferenceDuration(BaseModel, Generic[OptFloatT]):
     inference_duration: OptFloatT = Field(..., description="Inference duration")
+
+
+class Uptime(BaseModel, Generic[OptFloatT]):
+    uptime: OptFloatT = Field(..., description="Uptime")
