@@ -35,7 +35,7 @@ from .action.resource import (
     ResourceOperationActions,
     AnyResourceOperationAction,
     OptAnyResourceOperationAction,
-    Factory as ResourceOperationActionFactory,
+    ResourceOperationActionFactory,
 )
 from .base import BaseOperation
 from .context import Context as OperationContext
