@@ -26,13 +26,15 @@ class FlexibleLimit(BaseModel):
 
 
 class StrictLimit(BaseModel):
-    limit: Limit = Field(Limit.LIM_10, description="Page limit")
+    limit: Annotated[Limit, Field(Limit.LIM_10, description="Page limit")] = (
+        Limit.LIM_10
+    )
 
 
 class PageInfo(BaseModel):
-    data_count: Annotated[int, Field(..., description="Fetched data count", ge=0)] = 0
-    total_data: Annotated[int, Field(..., description="Total data count", ge=0)] = 0
-    total_pages: Annotated[int, Field(..., description="Total pages count", ge=1)] = 1
+    data_count: Annotated[int, Field(0, description="Fetched data count", ge=0)] = 0
+    total_data: Annotated[int, Field(0, description="Total data count", ge=0)] = 0
+    total_pages: Annotated[int, Field(1, description="Total pages count", ge=1)] = 1
 
 
 class BaseFlexiblePagination(FlexibleLimit, Page):
@@ -62,4 +64,4 @@ OptPaginationT = TypeVar("OptPaginationT", bound=OptAnyPagination)
 
 
 class PaginationMixin(BaseModel, Generic[OptPaginationT]):
-    pagination: OptPaginationT = Field(..., description="Pagination")
+    pagination: Annotated[OptPaginationT, Field(..., description="Pagination")]
