@@ -1,18 +1,18 @@
 from pydantic import BaseModel, Field
-from typing import Generic, List, Optional, TypeVar
+from typing import Generic, TypeVar
 from .data import DataPair, AnyDataT, DataMixin, ModelDataT
 from .metadata import MetadataMixin, AnyMetadataT, ModelMetadataT
 from .mixins.general import Other
-from .pagination import OptionalPaginationT, PaginationT, PaginationMixin
+from .pagination import OptPaginationT, PaginationT, PaginationMixin
 
 
 class Payload(
     Other,
     MetadataMixin[AnyMetadataT],
-    PaginationMixin[OptionalPaginationT],
+    PaginationMixin[OptPaginationT],
     DataMixin[AnyDataT],
     BaseModel,
-    Generic[AnyDataT, OptionalPaginationT, AnyMetadataT],
+    Generic[AnyDataT, OptPaginationT, AnyMetadataT],
 ):
     pass
 
@@ -67,50 +67,50 @@ class DeleteSingleDataPayload(
     pass
 
 
-class OptionalSingleDataPayload(
-    Payload[Optional[ModelDataT], None, ModelMetadataT],
+class OptSingleDataPayload(
+    Payload[ModelDataT | None, None, ModelMetadataT],
     Generic[ModelDataT, ModelMetadataT],
 ):
     pagination: None = None
 
 
 class MultipleDataPayload(
-    Payload[List[ModelDataT], PaginationT, ModelMetadataT],
+    Payload[list[ModelDataT], PaginationT, ModelMetadataT],
     Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     pass
 
 
 class CreateMultipleDataPayload(
-    Payload[DataPair[None, List[ModelDataT]], PaginationT, ModelMetadataT],
+    Payload[DataPair[None, list[ModelDataT]], PaginationT, ModelMetadataT],
     Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     pass
 
 
 class ReadMultipleDataPayload(
-    Payload[DataPair[List[ModelDataT], None], PaginationT, ModelMetadataT],
+    Payload[DataPair[list[ModelDataT], None], PaginationT, ModelMetadataT],
     Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     pass
 
 
 class UpdateMultipleDataPayload(
-    Payload[DataPair[List[ModelDataT], List[ModelDataT]], PaginationT, ModelMetadataT],
+    Payload[DataPair[list[ModelDataT], list[ModelDataT]], PaginationT, ModelMetadataT],
     Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     pass
 
 
 class DeleteMultipleDataPayload(
-    Payload[DataPair[List[ModelDataT], None], PaginationT, ModelMetadataT],
+    Payload[DataPair[list[ModelDataT], None], PaginationT, ModelMetadataT],
     Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     pass
 
 
-class OptionalMultipleDataPayload(
-    Payload[Optional[List[ModelDataT]], PaginationT, ModelMetadataT],
+class OptMultipleDataPayload(
+    Payload[list[ModelDataT] | None, PaginationT, ModelMetadataT],
     Generic[ModelDataT, PaginationT, ModelMetadataT],
 ):
     pass
