@@ -1,8 +1,8 @@
 from enum import StrEnum
 from pydantic import BaseModel, Field
-from typing import Annotated, Generic, List, Literal, Optional, TypeVar, overload
-from maleo.types.dict import OptionalStringToAnyDict
-from maleo.types.string import ListOfStrings
+from typing import Annotated, Generic, Literal, TypeVar, overload
+from maleo.types.dict import OptStrToAnyDict
+from maleo.types.string import ListOfStrs
 
 
 class AggregateField(StrEnum):
@@ -11,7 +11,7 @@ class AggregateField(StrEnum):
     SLUG = "slug"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
 
 
@@ -25,11 +25,9 @@ class ResourceIdentifier(BaseModel):
 
 class Resource(BaseModel):
     identifiers: Annotated[
-        List[ResourceIdentifier], Field(..., min_length=1, description="Identifiers")
+        list[ResourceIdentifier], Field(..., min_length=1, description="Identifiers")
     ]
-    details: Annotated[OptionalStringToAnyDict, Field(None, description="Details")] = (
-        None
-    )
+    details: Annotated[OptStrToAnyDict, Field(None, description="Details")] = None
 
     @overload
     def aggregate(
@@ -58,9 +56,9 @@ class Resource(BaseModel):
             return sep.join([id.slug for id in self.identifiers])
 
 
-OptionalResource = Optional[Resource]
-OptionalResourceT = TypeVar("OptionalResourceT", bound=OptionalResource)
+OptResource = Resource | None
+OptResourceT = TypeVar("OptResourceT", bound=OptResource)
 
 
-class ResourceMixin(BaseModel, Generic[OptionalResourceT]):
-    resource: OptionalResourceT = Field(..., description="Resource")
+class ResourceMixin(BaseModel, Generic[OptResourceT]):
+    resource: OptResourceT = Field(..., description="Resource")
