@@ -12,7 +12,7 @@ from maleo.types.boolean import BoolT
 from maleo.types.dict import StrToAnyDict
 from maleo.types.misc import IntOrStr, StrOrStrEnumT
 from maleo.types.string import OptStr, OptListOfDoubleStrs
-from .data import DataPair, AnyDataT, ModelDataT
+from .data import DataPair, AnyDataT, ModelDataT, PingData
 from .error.descriptor import (
     ErrorDescriptor,
     BadRequestErrorDescriptor,
@@ -265,6 +265,7 @@ AnyErrorResponse = (
 )
 ErrorResponseT = TypeVar("ErrorResponseT", bound=AnyErrorResponse)
 OptAnyErrorResponse = AnyErrorResponse | None
+OptErrorResponseT = TypeVar("OptErrorResponseT", bound=OptAnyErrorResponse)
 
 
 class ErrorFactory:
@@ -642,6 +643,15 @@ class SingleDataResponse(
         )
 
 
+class PingResponse(SingleDataResponse[PingData, None]):
+    data: Annotated[PingData, Field(PingData(), description="Ping response's data")] = (
+        PingData()
+    )
+    metadata: Annotated[None, Field(None, description="Ping response's metadata")] = (
+        None
+    )
+
+
 class CreateSingleDataResponse(
     CreateSingleDataPayload[ModelDataT, ModelMetadataT],
     CreateSingleDataSuccessDescriptor,
@@ -1017,11 +1027,15 @@ AnySuccessResponse = (
     | OptMultipleDataResponse[ModelDataT, PaginationT, ModelMetadataT]
 )
 SuccessResponseT = TypeVar("SuccessResponseT", bound=AnySuccessResponse)
+OptAnySuccessResponse = AnySuccessResponse | None
+OptSuccessResponseT = TypeVar("OptSuccessResponseT", bound=OptAnySuccessResponse)
 
 
 AnyResponse = AnyErrorResponse | AnySuccessResponse
 ResponseT = TypeVar("ResponseT", bound=AnyResponse)
+OptAnyResponse = AnyResponse | None
+OptResponseT = TypeVar("OptResponseT", bound=OptAnyResponse)
 
 
-class ResponseMixin(BaseModel, Generic[ResponseT]):
-    response: ResponseT = Field(..., description="Response")
+class ResponseMixin(BaseModel, Generic[OptResponseT]):
+    response: OptResponseT = Field(..., description="Response")
