@@ -17,13 +17,18 @@ from typing import (
     TypeVar,
     overload,
 )
-from maleo.enums.organization import ListOfOrganizationRoles
+from maleo.enums.organization import (
+    ListOfOrganizationRoles,
+    OrganizationType,
+    OptOrganizationType,
+)
 from maleo.enums.medical import (
     OptSeqOfMedicalRoles,
     OptListOfMedicalRoles,
     OptListOfMedicalRolesT,
 )
 from maleo.enums.system import ListOfSystemRoles
+from maleo.enums.user import UserType, OptUserType
 from maleo.types.integer import OptInt
 from maleo.types.string import (
     OptStr,
@@ -34,7 +39,7 @@ from maleo.types.string import (
 )
 from maleo.types.uuid import OptUUID
 from maleo.utils.exception import extract_details
-from ..mixins.identity import EntityIdentifier, OptEntityIdentifier
+from ..mixins.identity import EntityIdentifier
 from .enums import Domain, OptDomain, OptDomainT
 from .types import (
     ListOfDomainRoles,
@@ -61,32 +66,44 @@ class RequestCredentials(StarletteCredentials):
         domain: OptDomain = None,
         user_id: OptInt = None,
         user_uuid: OptUUID = None,
+        user_type: OptUserType = None,
         organization_id: OptInt = None,
         organization_uuid: OptUUID = None,
+        organization_type: OptOrganizationType = None,
         domain_roles: OptSeqOfDomainRoles = None,
         medical_roles: OptSeqOfMedicalRoles = None,
         scopes: OptSeqOfStrs = None,
     ):
         self.domain = domain
 
-        if user_id is None and user_uuid is None:
+        if user_id is None and user_uuid is None and user_type is None:
             self.user = None
-        elif user_id is not None and user_uuid is not None:
-            self.user = EntityIdentifier(id=user_id, uuid=user_uuid)
+        elif user_id is not None and user_uuid is not None and user_type is not None:
+            self.user = EntityIdentifier[UserType](
+                id=user_id, uuid=user_uuid, type=user_type
+            )
         else:
             raise ValueError(
-                "Both 'user_id' and 'user_uuid' must either be None or not None"
+                "Both 'user_id', 'user_uuid', and 'user_type' must either be None or not None"
             )
 
-        if organization_id is None and organization_uuid is None:
+        if (
+            organization_id is None
+            and organization_uuid is None
+            and organization_type is None
+        ):
             self.organization = None
-        elif organization_id is not None and organization_uuid is not None:
-            self.organization = EntityIdentifier(
-                id=organization_id, uuid=organization_uuid
+        elif (
+            organization_id is not None
+            and organization_uuid is not None
+            and organization_type is not None
+        ):
+            self.organization = EntityIdentifier[OrganizationType](
+                id=organization_id, uuid=organization_uuid, type=organization_type
             )
         else:
             raise ValueError(
-                "Both 'organization_id' and 'organization_uuid' must either be None or not None"
+                "Both 'organization_id', 'organization_uuid', and 'organization_type' must either be None or not None"
             )
 
         self.domain_roles: OptListOfDomainRoles = list(domain_roles) if domain_roles is not None else None  # type: ignore
@@ -126,8 +143,10 @@ class RequestUser(StarletteUser):
         return self._email
 
 
-UserT = TypeVar("UserT", bound=OptEntityIdentifier)
-OrganizationT = TypeVar("OrganizationT", bound=OptEntityIdentifier)
+UserT = TypeVar("UserT", bound=EntityIdentifier[UserType] | None)
+OrganizationT = TypeVar(
+    "OrganizationT", bound=EntityIdentifier[OrganizationType] | None
+)
 ScopesT = TypeVar("ScopesT", bound=OptListOfStrs)
 
 
@@ -157,17 +176,20 @@ class GenericCredentials(
 class BaseCredentials(
     GenericCredentials[
         OptDomain,
-        OptEntityIdentifier,
-        OptEntityIdentifier,
+        EntityIdentifier[UserType] | None,
+        EntityIdentifier[OrganizationType] | None,
         OptListOfDomainRoles,
         OptListOfMedicalRoles,
         OptListOfStrs,
     ]
 ):
     domain: Annotated[OptDomain, Field(None, description="Domain")] = None
-    user: Annotated[OptEntityIdentifier, Field(None, description="User")] = None
+    user: Annotated[
+        EntityIdentifier[UserType] | None, Field(None, description="User")
+    ] = None
     organization: Annotated[
-        OptEntityIdentifier, Field(None, description="Organization")
+        EntityIdentifier[OrganizationType] | None,
+        Field(None, description="Organization"),
     ] = None
     domain_roles: Annotated[
         OptListOfDomainRoles, Field(None, description="Domain Roles")
@@ -181,16 +203,19 @@ class BaseCredentials(
 class AuthenticatedCredentials(
     GenericCredentials[
         Domain,
-        EntityIdentifier,
-        OptEntityIdentifier,
+        EntityIdentifier[UserType],
+        EntityIdentifier[OrganizationType] | None,
         ListOfDomainRoles,
         OptListOfMedicalRoles,
         ListOfStrs,
     ]
 ):
     domain: Annotated[Domain, Field(..., description="Domain")]
-    user: Annotated[EntityIdentifier, Field(..., description="User")]
-    organization: Annotated[OptEntityIdentifier, Field(..., description="Organization")]
+    user: Annotated[EntityIdentifier[UserType], Field(..., description="User")]
+    organization: Annotated[
+        EntityIdentifier[OrganizationType] | None,
+        Field(..., description="Organization"),
+    ]
     domain_roles: Annotated[ListOfDomainRoles, Field(..., description="Domain Roles")]
     medical_roles: Annotated[
         OptListOfMedicalRoles, Field(..., description="Medical roles")
@@ -201,16 +226,18 @@ class AuthenticatedCredentials(
 class TenantCredentials(
     GenericCredentials[
         Literal[Domain.TENANT],
-        EntityIdentifier,
-        EntityIdentifier,
+        EntityIdentifier[UserType],
+        EntityIdentifier[OrganizationType],
         ListOfOrganizationRoles,
         OptListOfMedicalRoles,
         ListOfStrs,
     ]
 ):
     domain: Literal[Domain.TENANT] = Domain.TENANT
-    user: Annotated[EntityIdentifier, Field(..., description="User")]
-    organization: Annotated[EntityIdentifier, Field(..., description="Organization")]
+    user: Annotated[EntityIdentifier[UserType], Field(..., description="User")]
+    organization: Annotated[
+        EntityIdentifier[OrganizationType], Field(..., description="Organization")
+    ]
     domain_roles: Annotated[
         ListOfOrganizationRoles, Field(..., description="Domain Roles")
     ]
@@ -223,7 +250,7 @@ class TenantCredentials(
 class SystemCredentials(
     GenericCredentials[
         Literal[Domain.SYSTEM],
-        EntityIdentifier,
+        EntityIdentifier[UserType],
         None,
         ListOfSystemRoles,
         None,
@@ -231,7 +258,7 @@ class SystemCredentials(
     ]
 ):
     domain: Literal[Domain.SYSTEM] = Domain.SYSTEM
-    user: Annotated[EntityIdentifier, Field(..., description="User")]
+    user: Annotated[EntityIdentifier[UserType], Field(..., description="User")]
     organization: Annotated[None, Field(None, description="Organization")] = None
     domain_roles: Annotated[ListOfSystemRoles, Field(..., description="Domain Roles")]
     medical_roles: Annotated[None, Field(None, description="Medical roles")] = None
@@ -269,10 +296,12 @@ class AuthenticatedUser(GenericUser[Literal[True], OptStr]):
 
 
 class TenantUser(GenericUser[Literal[True], str]):
+    is_authenticated: Literal[True] = True
     organization: Annotated[str, Field(..., description="Organization")]
 
 
 class SystemUser(GenericUser[Literal[True], None]):
+    is_authenticated: Literal[True] = True
     organization: Annotated[None, Field(None, description="Organization")] = None
 
 
@@ -493,7 +522,7 @@ class AuthenticationMixin(BaseModel, Generic[OptAnyAuthenticationT]):
     authentication: OptAnyAuthenticationT = Field(..., description="Authentication")
 
 
-class Factory:
+class AuthenticationFactory:
     @overload
     @classmethod
     def extract(
