@@ -24,7 +24,7 @@ from maleo.enums.connection import Header, Protocol, OptProtocol
 from maleo.types.misc import BytesOrStr
 from maleo.types.string import ListOfStrs, OptStr
 from .enums import Domain, OptDomain
-from .token import TenantToken, SystemToken, AnyToken, Factory as TokenFactory
+from .token import TenantToken, SystemToken, AnyToken, TokenFactory
 
 
 class Scheme(StrEnum):
@@ -442,7 +442,7 @@ class BearerTokenAuth(httpx.Auth):
 AnyHTTPXAuthorization = APIKeyAuth | BearerTokenAuth
 
 
-class Factory:
+class AuthorizationFactory:
     @overload
     @classmethod
     def extract(
